<?php

/**
 * Provide a admin area view for setting instructor commission.
 *
 * This file is used to markup the instructor commission aspects of the plugin.
 *
 * @link       https://wbcomdesigns.com/plugins
 * @since      1.0.0
 *
 * @package    Ld_Dashboard
 * @subpackage Ld_Dashboard/admin/partials
 */

$args = array(
			'role' => 'ld_instructor',
		);
$instructors = get_users( $args );
$function_obj				 = Ld_Dashboard_Functions::instance();
$ld_dashboard_settings_data	 = $function_obj->ld_dashboard_settings_data();
$settings					 = $ld_dashboard_settings_data[ 'instructor_settings' ];

?>
<div class="wbcom-tab-content">
	<div class="wrap ld-dashboard-settings">						
		<div class="ld-dashboard-content container">
			<?php if( $instructors && is_array( $instructors )){ ?>
			<form method="post" action="options.php" enctype="multipart/form-data">
				<?php
				settings_fields( 'ld_dashboard_instructor_settings' );
				do_settings_sections( 'ld_dashboard_instructor_settings' );
				?>
				<div class="form-table">
					<div class="ld-grid-view-wrapper">
						<div class="ld-single-grid">
							<div class="ld-grid-label" scope="row">
								<label><?php esc_html_e('Global commission', 'ld-dashboard'); ?></label>
							</div>
							<div class="ld-grid-content">
								<span class="ld-decription"><?php esc_html_e('Enable this option if you want to enable commission on courses.', 'ld-dashboard'); ?></span>
								<label class="ld-dashboard-setting-switch">
									<input type="checkbox" class="ld-dashboard-setting" name="ld_dashboard_instructor_settings[enable-global-commission]" value="1" <?php checked($settings['enable-global-commission'], '1'); ?> data-id="enable-global-commission"/>
									<div class="ld-dashboard-setting round"></div>
								</label>
								<div id="enable-global-commission-bgcolor">
									<label><?php esc_html_e('Rate %', 'ld-dashboard'); ?></label>
									<div class="ld-tooltip"><i class="fa fa-info-circle" aria-hidden="true"></i><span class="ld-tooltiptext"><?php esc_html_e('Enter global commission rate for all course author.', 'ld-dashboard'); ?></span></div>
									<input type="number" min="0" max="100" name="ld_dashboard_instructor_settings[global-commission]"  value="<?php echo esc_attr($settings['global-commission']); ?>" />
								</div>
							</div>
						</div>
					</div>
					
					<?php submit_button(); ?>
					<?php wp_nonce_field('ld-dashboard-settings-submit', 'ld-dashboard-settings-submit'); ?>
				</div>
				<br /><br />
				<table id="ld-instructor-commission-update-tbl" class="ld-instructor-commission-update-tbl">
					<thead>
						<tr>
							<th><?php esc_html_e( 'Name', 'ld-dashboard' ); ?></th>
							<th><?php esc_html_e( 'User email', 'ld-dashboard' ); ?></th>
							<th><?php esc_html_e( 'Commission %', 'ld-dashboard' ); ?></th>
							<th><?php esc_html_e( 'Update', 'ld-dashboard' ); ?></th>
						</tr>
					</thead>
					<tbody>
						<?php foreach ( $instructors as $key => $ins_data ) { ?>
							<?php 
								$instructor_commission = ld_if_instructor_course_commission_set( $ins_data->ID );
								if( !$instructor_commission ) {
									$instructor_commission = ld_get_global_commission_rate();
								}
							?>
							<tr>
								<td><?php echo ( isset( $ins_data->data->display_name ) )?esc_html( $ins_data->data->display_name ):esc_html( $ins_data->data->user_login ); ?></td>
								<td><?php echo esc_html( $ins_data->data->user_email ); ?></td>
								<td>
									<input type="number" id="ld-commission-<?php echo $ins_data->ID; ?>" class="ld-commission-val" value="<?php echo esc_attr($instructor_commission); ?>" min="0" max="100">
								</td>
								<td>
									<a class="button button-primary ld-update-instructor-commision" data-id="ld-commission-<?php echo $ins_data->ID; ?>" data-instructor-id="<?php echo esc_attr( $ins_data->ID ); ?>"><?php esc_html_e( 'Update', 'ld-dashboard' ); ?></a>
								</td>
							</tr>
						<?php } ?>
					</tbody>
				</table>
				
			</form>
			<?php }else{ ?>
				<div class="no-instructors-found"><?php esc_html_e('No instructors are registered on the site.','ld-dashboard'); ?></div>
			<?php } ?>
		</div>
	</div>
</div>