<?php
/**
 * Class to define all the global variables related to plugin.
 *
 * @since      1.0.0
 * @author     Wbcom Designs
 * @package    Ld_Dashboard
 * @subpackage Ld_Dashboard/includes
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'Ld_Dashboard_Functions' ) ) {
	/**
	 * Class to add global variables of this plugin.
	 *
	 * @since    1.0.0
	 * @access   public
	 * @author   Wbcom Designs
	 */
	class Ld_Dashboard_Functions {
		/**
		 * The single instance of the class.
		 *
		 * @var   Ld_Dashboard_Functions
		 * @since 1.0.0
		 */
		protected static $instance = null;

		/**
		 * Main Ld_Dashboard_Functions Instance.
		 *
		 * Ensures only one instance of Ld_Dashboard_Functions is loaded or can be loaded.
		 *
		 * @since 1.0.0
		 * @static
		 */
		public static function instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		public function __construct() {
		}

		/**
		 * Get default general settings.
		 *
		 * @access public
		 * @since  1.0.0
		 * @author Wbcom Designs
		 * @return array
		 */
		public function default_general_settings() {
			$default_arr = array(
				'instructor-total-sales'         => 1,
				'instructor-total-sales-bgcolor' => '#f0f0f0',
				'course-count'                   => 1,
				'course-count-bgcolor'           => '#f0f0f0',
				'quizzes-count'                  => 1,
				'quizzes-count-bgcolor'          => '#f0f0f0',
				'assignments-count'              => 1,
				'assignments-completed-count'    => 1,
				'assignments-count-bgcolor'      => '#f0f0f0',
				'essays-pending-count'           => 1,
				'essays-pending-count-bgcolor'   => '#f0f0f0',
				'lessons-count'                  => 1,
				'lessons-count-bgcolor'          => '#f0f0f0',
				'topics-count'                   => 1,
				'topics-count-bgcolor'           => '#f0f0f0',
				'student-count'                  => 1,
				'student-details'                => 1,
				'student-count-bgcolor'          => '#f0f0f0',
				'instructor-statistics'          => 1,
				'course-progress'                => 1,
				'enable-global-commission'       => 1,
				'global-commission'              => 20,
				'welcome-message'                => esc_html__( 'Welcome back, %s', 'ld-dashboard' ),
				'welcomebar_image'               => '',
				'ins-earning'                    => 0,
				'ins-earning-bgcolor'            => '#b383e2',
				'enable-email-integration'       => 1,
				'enable-messaging-integration'   => 1,
			);

			return apply_filters( 'ld_dashboard_default_general_settings', $default_arr );
		}

		/**
		 * Get default activities settings.
		 *
		 * @access public
		 * @since  1.0.0
		 * @author Wbcom Designs
		 * @return array
		 */
		public function default_activities_settings() {
			$default_arr = array(
				'enable-activity' => 1,
				'activity-limit'  => 10,
			);

			return apply_filters( 'ld_dashboard_default_activities_settings', $default_arr );
		}

		/**
		 * Get all admin settings data.
		 *
		 * @since    1.0.0
		 * @access   public
		 * @author   Wbcom Designs
		 * @return   array
		 */
		public function ld_dashboard_settings_data() {
			$general                     = array();
			$activities                  = array();
			$default_general_settings    = $this->default_general_settings();
			$default_activities_settings = $this->default_activities_settings();
			if ( is_multisite() && is_plugin_active_for_network( plugin_basename( __FILE__ ) ) ) {
				$general_settings = get_site_option( 'ld_dashboard_general_settings' );
			} else {
				$general_settings = get_option( 'ld_dashboard_general_settings' );
			}
			
			if ( is_multisite() && is_plugin_active_for_network( plugin_basename( __FILE__ ) ) ) {
				$tiles_options = get_site_option( 'ld_dashboard_tiles_options' );
			} else {
				$tiles_options = get_option( 'ld_dashboard_tiles_options' );
			}
			
			if ( is_multisite() && is_plugin_active_for_network( plugin_basename( __FILE__ ) ) ) {
				$welcome_screen = get_site_option( 'ld_dashboard_welcome_screen' );
			} else {
				$welcome_screen = get_option( 'ld_dashboard_welcome_screen' );
			}
			
			if ( is_multisite() && is_plugin_active_for_network( plugin_basename( __FILE__ ) ) ) {
				$instructor_settings = get_site_option( 'ld_dashboard_instructor_settings' );
			} else {
				$instructor_settings = get_option( 'ld_dashboard_instructor_settings' );
			}
			
			/*
			if ( is_multisite() && is_plugin_active_for_network( plugin_basename( __FILE__ ) ) ) {
				$ld_dashboard_integration = get_site_option( 'ld_dashboard_integration' );
			} else {
				$ld_dashboard_integration = get_option( 'ld_dashboard_integration' );
			}
			*/

			if ( is_multisite() && is_plugin_active_for_network( plugin_basename( __FILE__ ) ) ) {
				$ld_dashboard_feed_settings = get_site_option( 'ld_dashboard_feed_settings' );
			} else {
				$ld_dashboard_feed_settings = get_option( 'ld_dashboard_feed_settings' );
			}

			if ( is_multisite() && is_plugin_active_for_network( plugin_basename( __FILE__ ) ) ) {
				$ld_dashboard_page_mapping = get_site_option( 'ld_dashboard_page_mapping' );
			} else {
				$ld_dashboard_page_mapping = get_option( 'ld_dashboard_page_mapping' );
			}

			/* General settings */
			if ( ! empty( $general_settings ) ) {
				if ( isset( $general_settings['welcome-screen'] ) ) {
					$general['welcome-screen'] = $general_settings['welcome-screen'];
				} else {
					$general['welcome-screen'] = 0;
				}
				
				if ( isset( $general_settings['statistics-tiles'] ) ) {
					$general['statistics-tiles'] = $general_settings['statistics-tiles'];
				} else {
					$general['statistics-tiles'] = 0;
				}				
				
				if ( isset( $general_settings['enable-email-integration'] ) ) {
					$general['enable-email-integration'] = $general_settings['enable-email-integration'];
				} else {
					$general['enable-email-integration'] = 0;
				}
				if ( isset( $general_settings['enable-messaging-integration'] ) ) {
					$general['enable-messaging-integration'] = $general_settings['enable-messaging-integration'];
				} else {
					$general['enable-messaging-integration'] = 0;
				}
				if ( isset( $general_settings['display-to-do'] ) ) {
					$general['display-to-do'] = $general_settings['display-to-do'];
				} else {
					$general['display-to-do'] = 0;
				}
			
				
				if ( ! empty( $general_settings['instructor-total-sales'] ) ) {
					$general['instructor-total-sales'] = $general_settings['instructor-total-sales'];
				} else {
					$general['instructor-total-sales'] = 0;
				}
				if ( isset( $general_settings['instructor-total-sales-bgcolor'] ) ) {
					$general['instructor-total-sales-bgcolor'] = $general_settings['instructor-total-sales-bgcolor'];
				} else {
					$general['instructor-total-sales-bgcolor'] = $default_general_settings['instructor-total-sales-bgcolor'];
				}
				
				if ( isset( $general_settings['student-details'] ) ) {
					$general['student-details'] = $general_settings['student-details'];
				} else {
					$general['student-details'] = 0;
				}
				
				if ( isset( $general_settings['instructor-statistics'] ) ) {
					$general['instructor-statistics'] = $general_settings['instructor-statistics'];
				} else {
					$general['instructor-statistics'] = 0;
				}
				if ( isset( $general_settings['course-progress'] ) ) {
					$general['course-progress'] = $general_settings['course-progress'];
				} else {
					$general['course-progress'] = 0;
				}
				
				if ( isset( $general_settings['instructor_registration_page'] ) ) {
					$general['instructor_registration_page'] = $general_settings['instructor_registration_page'];
				} else {
					$general['instructor_registration_page'] = 0;
				}
			} else {
				$general = $default_general_settings;
			}
			
			if ( isset( $instructor_settings['enable-global-commission'] ) ) {
				$instructor_settings['enable-global-commission'] = $instructor_settings['enable-global-commission'];
			} else {
				$instructor_settings['enable-global-commission'] = 0;
			}
			if ( isset( $instructor_settings['global-commission'] ) ) {
				$instructor_settings['global-commission'] = $instructor_settings['global-commission'];
			} else {
				$instructor_settings['global-commission'] = 0;
			}

			/* LD welcome screen */
			if ( isset( $welcome_screen['welcome-message'] ) ) {
				$welcome_screen['welcome-message'] = $welcome_screen['welcome-message'];
			} else {
				$welcome_screen['welcome-message'] = $default_general_settings['welcome-message'];
			}

			if ( isset( $welcome_screen['welcomebar_image'] ) ) {
				$welcome_screen['welcomebar_image'] = $welcome_screen['welcomebar_image'];
			} else {
				$welcome_screen['welcomebar_image'] = $default_general_settings['welcomebar_image'];
			}
			
			
			/* LD tiles options */
			if ( isset( $tiles_options['course-count'] ) ) {
				$tiles_options['course-count'] = $tiles_options['course-count'];
			} else {
				$tiles_options['course-count'] = 0;
			}
			if ( isset( $tiles_options['course-count-bgcolor'] ) ) {
				$tiles_options['course-count-bgcolor'] = $tiles_options['course-count-bgcolor'];
			} else {
				$tiles_options['course-count-bgcolor'] = $default_general_settings['course-count-bgcolor'];
			}
			if ( isset( $tiles_options['quizzes-count'] ) ) {
				$tiles_options['quizzes-count'] = $tiles_options['quizzes-count'];
			} else {
				$tiles_options['quizzes-count'] = 0;
			}
			if ( isset( $tiles_options['quizzes-count-bgcolor'] ) ) {
				$tiles_options['quizzes-count-bgcolor'] = $tiles_options['quizzes-count-bgcolor'];
			} else {
				$tiles_options['quizzes-count-bgcolor'] = $default_general_settings['quizzes-count-bgcolor'];
			}
			if ( isset( $tiles_options['assignments-count'] ) ) {
				$tiles_options['assignments-count'] = $tiles_options['assignments-count'];
			} else {
				$tiles_options['assignments-count'] = 0;
			}
			if ( isset( $tiles_options['assignments-completed-count'] ) ) {
				$tiles_options['assignments-completed-count'] = $tiles_options['assignments-completed-count'];
			} else {
				$tiles_options['assignments-completed-count'] = 0;
			}
			if ( isset( $tiles_options['assignments-count-bgcolor'] ) ) {
				$tiles_options['assignments-count-bgcolor'] = $tiles_options['assignments-count-bgcolor'];
			} else {
				$tiles_options['assignments-count-bgcolor'] = $default_general_settings['assignments-count-bgcolor'];
			}
			if ( isset( $tiles_options['essays-pending-count'] ) ) {
				$tiles_options['essays-pending-count'] = $tiles_options['essays-pending-count'];
			} else {
				$tiles_options['essays-pending-count'] = 0;
			}
			if ( isset( $tiles_options['essays-pending-count-bgcolor'] ) ) {
				$tiles_options['essays-pending-count-bgcolor'] = $tiles_options['essays-pending-count-bgcolor'];
			} else {
				$tiles_options['essays-pending-count-bgcolor'] = $default_general_settings['essays-pending-count-bgcolor'];
			}
			if ( isset( $tiles_options['lessons-count'] ) ) {
				$tiles_options['lessons-count'] = $tiles_options['lessons-count'];
			} else {
				$tiles_options['lessons-count'] = 0;
			}
			if ( isset( $tiles_options['lessons-count-bgcolor'] ) ) {
				$tiles_options['lessons-count-bgcolor'] = $tiles_options['lessons-count-bgcolor'];
			} else {
				$tiles_options['lessons-count-bgcolor'] = $default_general_settings['lessons-count-bgcolor'];
			}
			if ( isset( $tiles_options['topics-count'] ) ) {
				$tiles_options['topics-count'] = $tiles_options['topics-count'];
			} else {
				$tiles_options['topics-count'] = 0;
			}
			if ( isset( $tiles_options['topics-count-bgcolor'] ) ) {
				$tiles_options['topics-count-bgcolor'] = $tiles_options['topics-count-bgcolor'];
			} else {
				$tiles_options['topics-count-bgcolor'] = $default_general_settings['topics-count-bgcolor'];
			}
			if ( isset( $tiles_options['student-count'] ) ) {
				$tiles_options['student-count'] = $tiles_options['student-count'];
			} else {
				$tiles_options['student-count'] = 0;
			}
			if ( isset( $tiles_options['student-count-bgcolor'] ) ) {
				$tiles_options['student-count-bgcolor'] = $tiles_options['student-count-bgcolor'];
			} else {
				$tiles_options['student-count-bgcolor'] = $default_general_settings['student-count-bgcolor'];
			}
			
			if ( isset( $tiles_options['ins-earning'] ) ) {
				$tiles_options['ins-earning'] = $tiles_options['ins-earning'];
			} else {
				$tiles_options['ins-earning'] = 0;
			}
			if ( isset( $tiles_options['ins-earning-bgcolor'] ) ) {
				$tiles_options['ins-earning-bgcolor'] = $tiles_options['ins-earning-bgcolor'];
			} else {
				$tiles_options['ins-earning-bgcolor'] = $tiles_options['ins-earning-bgcolor'];
			}

			/*  LD Feed settings */
			if ( isset( $ld_dashboard_feed_settings['disable-live-feed'] ) ) {
				$ld_dashboard_feed_settings['disable-live-feed'] = $ld_dashboard_feed_settings['disable-live-feed'];
			} else {
				$ld_dashboard_feed_settings['disable-live-feed'] = 0;
			}

			if ( isset( $ld_dashboard_feed_settings['disable_user_roles_live_feed'] ) ) {
				$ld_dashboard_feed_settings['disable_user_roles_live_feed'] = $ld_dashboard_feed_settings['disable_user_roles_live_feed'];
			} else {
				$ld_dashboard_feed_settings['disable_user_roles_live_feed'] = 0;
			}
			
			

			/*  LD Page Mapping */
			if ( isset( $ld_dashboard_page_mapping['my_dashboard_page'] ) ) {
				$ld_dashboard_page_mapping['my_dashboard_page'] = $ld_dashboard_page_mapping['my_dashboard_page'];
			} else {
				$ld_dashboard_page_mapping['my_dashboard_page'] = 0;
			}
			if ( isset( $ld_dashboard_page_mapping['instructor_registration_page'] ) ) {
				$ld_dashboard_page_mapping['instructor_registration_page'] = $ld_dashboard_page_mapping['instructor_registration_page'];
			} else {
				$ld_dashboard_page_mapping['instructor_registration_page'] = 0;
			}

			/* Images settings */
			if ( isset( $activities_settings ) ) {
				if ( ! empty( $activities_settings['enable-activity'] ) ) {
					$activities['enable-activity'] = $activities_settings['enable-activity'];
				} else {
					$activities['enable-activity'] = 0;
				}
				if ( ! empty( $activities_settings['activity-limit'] ) ) {
					$activities['activity-limit'] = $activities_settings['activity-limit'];
				} else {
					$activities['activity-limit'] = $default_activities_settings['activity-limit'];
				}
			} else {
				$activities = $default_activities_settings;
			}

			$settings = array(
				'general_settings'           => $general,
				'tiles_options'           	 => $tiles_options,
				'welcome_screen'           	 => $welcome_screen,
				'ld_dashboard_feed_settings' => $ld_dashboard_feed_settings,
				//'ld_dashboard_integration' => $ld_dashboard_integration,
				'ld_dashboard_page_mapping'  => $ld_dashboard_page_mapping,
				'instructor_settings'  		 => $instructor_settings,
				'activities_settings'        => $activities,
			);

			return $settings;
		}

	}
}
